Package: ShinyWizard
Title: An Interactive Wizard to Design, Build, and Deploy R Packages
        Demo Presentation
Version: 1.1.3.11
Authors@R: 
    person("Rafal", "Urniaz", , "rafal.urniaz@cantab.net", role = c("aut", "cre"),
           comment = c(ORCID = "0000-0003-0192-2165"))
Description: Design, build, and deploy R packages demo presentations by an interactive wizard. Set up unique title, logo and themes. Add personalized tabs exposing applicability. And deploy as a part of a package or an independent app. 
License: GPL (>= 3)
Encoding: UTF-8
Imports: base, rstudioapi
RoxygenNote: 7.3.2
Suggests: testthat (>= 3.0.0), devtools, shinythemes, shinydashboard,
        shinyWidgets, shinyjs, yaml, readr, stringr, bslib, reshape2,
        shinytest2
Config/testthat/edition: 3
NeedsCompilation: no
Packaged: 2024-10-26 00:12:40 UTC; urniaz
Author: Rafal Urniaz [aut, cre] (<https://orcid.org/0000-0003-0192-2165>)
Maintainer: Rafal Urniaz <rafal.urniaz@cantab.net>
Repository: CRAN
Date/Publication: 2024-10-28 13:00:02 UTC
Built: R 4.6.0; ; 2026-04-25 12:47:48 UTC; unix
